@@ -1,6 +1,7 @@
 import os
 import ssl
 import time
+import fcntl
 import shutil
 import socket
 import asyncio
@@ -728,6 +729,8 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         'mirror': {
             'description': 'A telepath URL for our upstream mirror (we must be a backup!).',
             'type': 'string',
+            'hidedocs': True,
+            'hidecmdl': True,
         },
         'auth:passwd': {
             'description': 'Set to <passwd> (local only) to bootstrap the root user password.',
@@ -771,7 +774,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
             'hidecmdl': True,
         },
         'backup:dir': {
-            'description': 'A directory outside the service directory where backups will be saved.',
+            'description': 'A directory outside the service directory where backups will be saved. Defaults to ./backups in the service storage directory.',
             'type': 'string',
         },
         'aha:name': {
@@ -918,9 +921,10 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
             with open(path, 'w') as fd:
                 fd.write(guid)
 
-        # read our guid file
-        with open(path, 'r') as fd:
-            self.iden = fd.read().strip()
+        # read & lock our guid file
+        self._cellguidfd = s_common.genfile(path)
+        self.iden = self._cellguidfd.read().decode().strip()
+        self._getCellLock()
 
         self.donexslog = self.conf.get('nexslog:en')
 
@@ -931,7 +935,10 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
                 mesg = 'backup:dir must not be within the service directory'
                 raise s_exc.BadConfValu(mesg=mesg)
 
-            backdirn = s_common.gendir(backdirn)
+        else:
+            backdirn = s_common.genpath(self.dirn, 'backups')
+
+        backdirn = s_common.gendir(backdirn)
 
         self.backdirn = backdirn
         self.backuprunning = False  # Whether a backup is currently running
@@ -1027,6 +1034,28 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         # phase 5 - service networking
         await self.initServiceNetwork()
 
+    async def fini(self):
+        '''Fini override that ensures locking teardown order.'''
+        # we inherit from Pusher to make the Cell a Base subclass
+        retn = await s_nexus.Pusher.fini(self)
+        if retn == 0:
+            self._onFiniCellGuid()
+        return retn
+
+    def _onFiniCellGuid(self):
+        fcntl.lockf(self._cellguidfd, fcntl.LOCK_UN)
+        self._cellguidfd.close()
+
+    def _getCellLock(self):
+        cmd = fcntl.LOCK_EX | fcntl.LOCK_NB
+        try:
+            fcntl.lockf(self._cellguidfd, cmd)
+        except BlockingIOError:
+            # Raised when the a lock is unable to be obtained on cell.guid file.
+            ctyp = self.getCellType()
+            mesg = f'Cannot start the {ctyp}, another process is already running it.'
+            raise s_exc.FatalErr(mesg=mesg) from None
+
     async def _execCellUpdates(self):
         # implement to apply updates to a fully initialized active cell
         # ( and do so using _bumpCellVers )
@@ -1627,6 +1656,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
     async def iterBackupArchive(self, name, user):
 
         success = False
+        loglevel = logging.WARNING
 
         path = self._reqBackDirn(name)
         cellguid = os.path.join(path, 'cell.guid')
@@ -1657,8 +1687,11 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         except (asyncio.CancelledError, Exception) as e:
 
-            if not isinstance(e, asyncio.CancelledError):
-                logger.exception('Error during backup streaming.')
+            # We want to log all exceptions here, an asyncio.CancelledError
+            # could be the result of a remote link terminating due to the
+            # backup stream being completed, prior to this function
+            # finishing.
+            logger.exception('Error during backup streaming.')
 
             if proc:
                 proc.terminate()
@@ -1668,16 +1701,18 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         else:
             success = True
+            loglevel = logging.DEBUG
             self.backlastuploaddt = datetime.datetime.now()
 
         finally:
             phrase = 'successfully' if success else 'with failure'
-            logger.debug(f'iterBackupArchive completed {phrase} for {name}')
+            logger.log(loglevel, f'iterBackupArchive completed {phrase} for {name}')
             raise s_exc.DmonSpawn(mesg=mesg)
 
     async def iterNewBackupArchive(self, user, name=None, remove=False):
 
         success = False
+        loglevel = logging.WARNING
 
         if name is None:
             name = time.strftime('%Y%m%d%H%M%S', datetime.datetime.now().timetuple())
@@ -1719,8 +1754,11 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         except (asyncio.CancelledError, Exception) as e:
 
-            if not isinstance(e, asyncio.CancelledError):
-                logger.exception('Error during backup streaming.')
+            # We want to log all exceptions here, an asyncio.CancelledError
+            # could be the result of a remote link terminating due to the
+            # backup stream being completed, prior to this function
+            # finishing.
+            logger.exception('Error during backup streaming.')
 
             if proc:
                 proc.terminate()
@@ -1730,6 +1768,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         else:
             success = True
+            loglevel = logging.DEBUG
             self.backlastuploaddt = datetime.datetime.now()
 
         finally:
@@ -1739,7 +1778,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
                 logger.debug(f'Removed {path}')
 
             phrase = 'successfully' if success else 'with failure'
-            logger.debug(f'iterNewBackupArchive completed {phrase} for {name}')
+            logger.log(loglevel, f'iterNewBackupArchive completed {phrase} for {name}')
             raise s_exc.DmonSpawn(mesg=mesg)
 
     async def isUserAllowed(self, iden, perm, gateiden=None):
@@ -2350,7 +2389,11 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         s_coro.set_pool_logging(logger, logconf=conf['_log_conf'])
 
-        cell = await cls.anit(opts.dirn, conf=conf)
+        try:
+            cell = await cls.anit(opts.dirn, conf=conf)
+        except:
+            logger.exception(f'Error starting cell at {opts.dirn}')
+            raise
 
         try:
 
