@@ -117,23 +117,26 @@ class CryptoModule(s_module.CoreModule):
             'forms': (
 
                 ('crypto:payment:input', {}, (
+                    ('transaction', ('crypto:currency:transaction', {}), {
+                        'doc': 'The transaction the payment was input to.'}),
                     ('address', ('crypto:currency:address', {}), {
                         'doc': 'The address which paid into the transaction.'}),
                     ('value', ('econ:price', {}), {
                         'doc': 'The value of the currency paid into the transaction.'}),
                 )),
                 ('crypto:payment:output', {}, (
+                    ('transaction', ('crypto:currency:transaction', {}), {
+                        'doc': 'The transaction the payment was output from.'}),
                     ('address', ('crypto:currency:address', {}), {
                         'doc': 'The address which received payment from the transaction.'}),
                     ('value', ('econ:price', {}), {
                         'doc': 'The value of the currency recieved from the transaction.'}),
                 )),
                 ('crypto:currency:transaction', {}, (
-                    ('hash', ('str', {'lower': True, 'regex': '^0x[0-9a-f]+$'}), {
+                    ('hash', ('hex', {}), {
                         'doc': 'The unique transaction hash for the transaction.'}),
                     ('desc', ('str', {}), {
                         'doc': 'An analyst specified description of the transaction.'}),
-
                     ('block', ('crypto:currency:block', {}), {
                         'doc': 'The block which records the transaction.'}),
                     ('block:coin', ('crypto:currency:coin', {}), {
@@ -153,9 +156,11 @@ class CryptoModule(s_module.CoreModule):
                     ('from', ('crypto:currency:address', {}), {
                         'doc': 'The source address of the transaction.'}),
                     ('inputs', ('array', {'type': 'crypto:payment:input', 'sorted': True, 'uniq': True}), {
-                        'doc': 'An array of payment inputs to the transaction.'}),
+                        'deprecated': True,
+                        'doc': 'Deprecated. Please use crypto:payment:input:transaction.'}),
                     ('outputs', ('array', {'type': 'crypto:payment:output', 'sorted': True, 'uniq': True}), {
-                        'doc': 'An array of payment outputs from the transaction.'}),
+                        'deprecated': True,
+                        'doc': 'Deprecated. Please use crypto:payment:output:transaction.'}),
                     ('fee', ('econ:price', {}), {
                         'doc': 'The total fee paid to execute the transaction.'}),
                     ('value', ('econ:price', {}), {
@@ -179,10 +184,10 @@ class CryptoModule(s_module.CoreModule):
 
                 ('crypto:currency:block', {}, (
                     ('coin', ('crypto:currency:coin', {}), {
-                        'doc': 'The coin/blockchain this block resides on.'}),
+                        'doc': 'The coin/blockchain this block resides on.', 'ro': True, }),
                     ('offset', ('int', {}), {
-                        'doc': 'The index of this block.'}),
-                    ('hash', ('str', {'lower': True, 'regex': '^0x[0-9a-f]+$'}), {
+                        'doc': 'The index of this block.', 'ro': True, }),
+                    ('hash', ('hex', {}), {
                         'doc': 'The unique hash for the block.'}),
                     ('minedby', ('crypto:currency:address', {}), {
                         'doc': 'The address which mined the block.'}),
@@ -207,9 +212,9 @@ class CryptoModule(s_module.CoreModule):
                 )),
                 ('crypto:smart:token', {}, (
                     ('contract', ('crypto:smart:contract', {}), {
-                            'doc': 'The smart contract which defines and manages the token.'}),
+                            'doc': 'The smart contract which defines and manages the token.', 'ro': True, }),
                     ('tokenid', ('hugenum', {}), {
-                            'doc': 'The token ID.'}),
+                            'doc': 'The token ID.', 'ro': True, }),
                     ('owner', ('crypto:currency:address', {}), {
                             'doc': 'The address which currently owns the token.'}),
                     ('nft:url', ('inet:url', {}), {
@@ -231,9 +236,9 @@ class CryptoModule(s_module.CoreModule):
 
                 ('crypto:currency:address', {}, (
                     ('coin', ('crypto:currency:coin', {}), {
-                        'doc': 'The crypto coin to which the address belongs.'}),
+                        'doc': 'The crypto coin to which the address belongs.', 'ro': True, }),
                     ('iden', ('str', {}), {
-                        'doc': 'The coin specific address identifier.'}),
+                        'doc': 'The coin specific address identifier.', 'ro': True, }),
                     ('desc', ('str', {}), {
                         'doc': 'A free-form description of the address.'}),
                     ('contact', ('ps:contact', {}), {
@@ -242,9 +247,9 @@ class CryptoModule(s_module.CoreModule):
 
                 ('crypto:currency:client', {}, (
                     ('inetaddr', ('inet:client', {}), {
-                        'doc': 'The Internet client address observed using the crypto currency address.'}),
+                        'doc': 'The Internet client address observed using the crypto currency address.', 'ro': True, }),
                     ('coinaddr', ('crypto:currency:address', {}), {
-                        'doc': 'The crypto currency address observed in use the the Internet client.'}),
+                        'doc': 'The crypto currency address observed in use the the Internet client.', 'ro': True, }),
                 )),
 
                 ('hash:md5', {}, ()),
@@ -269,9 +274,9 @@ class CryptoModule(s_module.CoreModule):
 
                 ('crypto:x509:signedfile', {}, (
                     ('cert', ('crypto:x509:cert', {}), {
-                        'doc': 'The certificate for the key which signed the file.'}),
+                        'doc': 'The certificate for the key which signed the file.', 'ro': True, }),
                     ('file', ('file:bytes', {}), {
-                        'doc': 'The file which was signed by the certificates key.'}),
+                        'doc': 'The file which was signed by the certificates key.', 'ro': True, }),
                 )),
 
                 ('crypto:x509:crl', {}, (
@@ -283,9 +288,9 @@ class CryptoModule(s_module.CoreModule):
 
                 ('crypto:x509:revoked', {}, (
                     ('crl', ('crypto:x509:crl', {}), {
-                        'doc': 'The CRL which revoked the certificate.'}),
+                        'doc': 'The CRL which revoked the certificate.', 'ro': True, }),
                     ('cert', ('crypto:x509:cert', {}), {
-                        'doc': 'The certificate revoked by the CRL.'}),
+                        'doc': 'The certificate revoked by the CRL.', 'ro': True, }),
                 )),
 
                 ('crypto:x509:cert', {}, (
