@@ -2,6 +2,8 @@ import asyncio
 import logging
 
 import synapse.exc as s_exc
+
+import synapse.lib.chop as s_chop
 import synapse.lib.types as s_types
 import synapse.lib.module as s_module
 import synapse.lib.version as s_version
@@ -88,15 +90,17 @@ class Cpe23Str(s_types.Str):
     '''
     CPE 2.3 Formatted String
 
-    https://nvlpubs.nist.gov/nistpubs/Legacy/IR/nistir7695.pdf
+    ::
 
-    (Section 6.2)
+        https://nvlpubs.nist.gov/nistpubs/Legacy/IR/nistir7695.pdf
 
-    cpe:2.3: part : vendor : product : version : update : edition :
-        language : sw_edition : target_sw : target_hw : other
+        (Section 6.2)
 
-    * = "any"
-    - = N/A
+        cpe:2.3: part : vendor : product : version : update : edition :
+            language : sw_edition : target_sw : target_hw : other
+
+        * = "any"
+        - = N/A
     '''
     def __init__(self, modl, name, info, opts):
         opts['lower'] = True
@@ -330,7 +334,8 @@ class ItModule(s_module.CoreModule):
                     'doc': 'A screenshot of a host.',
                     'interfaces': ('it:host:activity',),
                 }),
-                ('it:sec:cve', ('str', {'lower': True, 'regex': r'(?i)^CVE-[0-9]{4}-[0-9]{4,}$'}), {
+                ('it:sec:cve', ('str', {'lower': True, 'replace': s_chop.unicode_dashes_replace,
+                                        'regex': r'(?i)^CVE-[0-9]{4}-[0-9]{4,}$'}), {
                     'doc': 'A vulnerability as designated by a Common Vulnerabilities and Exposures (CVE) number.',
                     'ex': 'cve-2012-0158'
                 }),
@@ -623,7 +628,7 @@ class ItModule(s_module.CoreModule):
                     }),
                 )),
                 ('it:domain', {}, (
-                    ('name', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                    ('name', ('str', {'lower': True, 'onespace': True}), {
                         'doc': 'The name of the domain.',
                     }),
                     ('desc', ('str', {}), {
@@ -634,7 +639,7 @@ class ItModule(s_module.CoreModule):
                     }),
                 )),
                 ('it:network', {}, (
-                    ('name', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                    ('name', ('str', {'lower': True, 'onespace': True}), {
                         'doc': 'The name of the network.',
                     }),
                     ('desc', ('str', {}), {
@@ -690,7 +695,7 @@ class ItModule(s_module.CoreModule):
                     }),
                 )),
                 ('it:group', {}, (
-                    ('name', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                    ('name', ('str', {'lower': True, 'onespace': True}), {
                         'doc': 'The name of the group.',
                     }),
                     ('desc', ('str', {}), {
@@ -991,7 +996,7 @@ class ItModule(s_module.CoreModule):
                 )),
                 ('it:prod:hardwaretype', {}, ()),
                 ('it:prod:hardware', {}, (
-                    ('name', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                    ('name', ('str', {'lower': True, 'onespace': True}), {
                         'doc': 'The display name for this hardware specification.'}),
                     ('type', ('it:prod:hardwaretype', {}), {
                         'doc': 'The type of hardware.'}),
@@ -1002,9 +1007,9 @@ class ItModule(s_module.CoreModule):
                         'doc': 'The NIST CPE 2.3 string specifying this hardware.'}),
                     ('make', ('ou:name', {}), {
                         'doc': 'The name of the organization which manufactures this hardware.'}),
-                    ('model', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                    ('model', ('str', {'lower': True, 'onespace': True}), {
                         'doc': 'The model name or number for this hardware specification.'}),
-                    ('version', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                    ('version', ('str', {'lower': True, 'onespace': True}), {
                         'doc': 'Version string associated with this hardware specification.'}),
                     ('released', ('time', {}), {
                         'doc': 'The initial release date for this hardware.'}),
@@ -1756,6 +1761,10 @@ class ItModule(s_module.CoreModule):
                         'doc': 'Contact info for the author of the YARA rule.'}),
                     ('version', ('it:semver', {}), {
                         'doc': 'The current version of the rule.'}),
+                    ('created', ('time', {}), {
+                        'doc': 'The time the YARA rule was initially created.'}),
+                    ('updated', ('time', {}), {
+                        'doc': 'The time the YARA rule was most recently modified.'}),
                     ('enabled', ('bool', {}), {
                         'doc': 'The rule enabled status to be used for YARA evaluation engines.'}),
                 )),
